function res = cyclrot(mat,phi)
//-----------------------------------------------------------------------  
// function res = cyclrot(mat,phi)
//
// implementation of cyclic rotation of a matrix around its center using 
// nearest neighbour interpolation
//
// input:    mat          matrix to be rotated
//           phi          rotation_angle, real value
//
// output:   res          rotated matrix, e.g.
//                        cyclrot_interp([1 2 3; 4 5 6; 7 8 9], pi/2)
//                        = [3 6 9; 2 5 8 ; 1 4 7]
//
//-----------------------------------------------------------------------  
//   $RCSfile: cyclrot.sci,v $
//  $Revision: 1.1 $
//      $Date: 2002/09/10 15:15:36 $
//  Copyright: IIF-LMB $Author: poluru $
//
//-----------------------------------------------------------------------
//  $Log: cyclrot.sci,v $
//  Revision 1.1  2002/09/10 15:15:36  poluru
//  "macros" directory structure is created
//
//-----------------------------------------------------------------------

  
  [out,in] = argn(0);
  
  if in~=2, 
    error('wrong number of input arguments.');
  end;
  
  [ys, xs] = size(mat);
  
  // matrices for calculation of coordinates of 'sampling points'
  xi_org = ones(ys,1) * (1:xs)
  yi_org = (1:ys)' * ones(1,xs)
    
  xoffset = (1+xs)/2;
  yoffset = (1+ys)/2;
  
  yi_new =   (yi_org - yoffset) * cos(-phi) - ...
      (xi_org - xoffset) * sin(-phi) ...
      + yoffset;
  
  xi_new =   (yi_org - yoffset) * sin(-phi) + ...
      (xi_org - xoffset) * cos(-phi) ...
      + xoffset;
  
  // nearest-neighbor coordinates in original range.
  
  yi_new = pmodulo(round(yi_new) -1, ys) + 1;
  xi_new = pmodulo(round(xi_new) -1, xs) + 1;
  
  res = index_mat(mat,yi_new,xi_new);

endfunction;




